==> je_editor_dev-0.0.164-py3-none-any.whl: je_editor/utils/multi_language/english.py <==
english_word_dict = {
    # Main
    "application_name": "JEditor",
    # Tab
    "tab_name_editor": "Editor",
    "tab_name_web_browser": "Web Browser",
    "tab_name_frontengine": "FrontEngine",
    # Browser
    "browser_download_detail": "Download Detail",
    "browser_find_text": "Find Text",
    "browser_find_text_input": "Input a text to find",
    "browser_back_button": "Back",
    "browser_forward_button": "Forward",
    "browser_reload_button": "Reload",
    "browser_search_button": "Search",
    # Dialog
    "dialog_create_file": "Create File",
    "dialog_input_file_name": "Please enter right file name",
    "dialog_search_next": "Search next",
    "dialog_search_back": "Search back",
    # Editor
    "editor_code_result": "Code result",
    "editor_format_check": "Format checker",
    # Check Code Style Menu
    "check_code_style_menu_label": "Check Code Style",
    "yapf_reformat_label": "yapf",
    "reformat_json_label": "Reformat JSON",
    # Dock Menu
    "dock_menu_label": "Dock",
    "dock_browser_label": "New Dock Browser",
    "dock_stackoverflow_label": "New Dock Stackoverflow",
    "dock_editor_label": "New Dock Editor",
    "dock_frontengine_label": "New Dock FrontEngine",
    "dock_editor_title": "Editor",
    "dock_frontengine_title": "FrontEngine",
    "dock_browser_title": "Browser",
    # File Menu
    "file_menu_label": "File",
    "file_menu_new_file_label": "New File",
    "file_menu_open_file_label": "Open File",
    "file_menu_open_folder_label": "Open Folder",
    "file_menu_save_file_label": "Save File",
    "file_menu_encoding_label": "Encodings",
    "file_menu_font_label": "Font",
    "file_menu_font_size_label": "Font Size",
    # Help Menu
    "help_menu_label": "Help",
    "help_menu_open_github_label": "GitHub",
    "help_menu_open_doc_label": "Doc",
    "help_menu_open_about_label": "About",
    "help_menu_open_re_edge_gpt_doc_label": "Open ReEdgeGPT Doc",
    "help_menu_open_re_edge_gpt_github_label": "Open ReEdgeGPT GitHub",
    # Python Env Menu
    "python_env_menu_label": "Python Env",
    "python_env_menu_create_venv_label": "Create venv",
    "python_env_menu_pip_upgrade_label": "pip upgrade package",
    "python_env_menu_pip_label": "pip package",
    "python_env_menu_choose_interpreter_label": "Choose python interpreter",
    "python_env_menu_creating_venv_message": "Creating venv please waiting for shell exit code.",
    "python_env_menu_venv_exists": "venv already exists.",
    "python_env_menu_please_create_venv": "Please create venv first.",
    "python_env_menu_install_package_messagebox_title": "Install Package",
    "python_env_menu_install_package_messagebox_label": "What Package you want to install",
    "python_env_menu_install_or_update_package_messagebox_label": "What Package you want to install or update",
    # Run Menu
    "run_menu_label": "Run",
    "run_menu_run_program_label": "Run Program",
    "run_menu_run_on_shell_label": "Run On Shell",
    "run_menu_clear_result_label": "Clean Result",
    "run_menu_stop_program_label": "Stop All Program",
    "run_menu_run_help_label": "Run Help",
    "run_menu_shell_help_label": "Shell Help",
    "run_menu_run_help_tip": """
If you are unable to run a Python program, please make sure you are have python interpreter,
And if python conflict please choose another interpreter.
        """,
    "run_menu_shell_run_tip": """
When executing a shell command, if you encounter a decoding error, 
please make sure that the current encoding is consistent with the default encoding of the system shell.
        """,
    # Style Menu
    "style_menu_label": "UI Style",
    # Tab Menu
    "tab_menu_label": "Tab",
    "tab_menu_add_editor_label": "Add Editor Tab",
    "tab_menu_add_frontengine_label": "Add FrontEngine Tab",
    "tab_menu_add_web_label": "Add Web Browser Tab",
    "tab_menu_add_stackoverflow_label": "Add Stackoverflow Tab",
    "tab_menu_editor_tab_name": "Editor",
    "tab_menu_frontengine_tab_name": "FrontEngine",
    "tab_menu_web_tab_name": "WEB Browser",
    "tab_menu_stackoverflow_tab_name": "Stackoverflow",
    # Text Menu
    "text_menu_label": "Text",
    "text_menu_label_font": "Font",
    "text_menu_label_font_size": "Font Size",
    # System tray
    "system_tray_hide": "Hide",
    "system_tray_maximized": "Maximized",
    "system_tray_normal": "Normal",
    "system_tray_close": "Close",

}

==> je_editor_dev-0.0.166-py3-none-any.whl: je_editor/utils/multi_language/english.py <==
english_word_dict = {
    # Main
    "application_name": "JEditor",
    # Tab
    "tab_name_editor": "Editor",
    "tab_name_web_browser": "Web Browser",
    "tab_name_frontengine": "FrontEngine",
    # Browser
    "browser_download_detail": "Download Detail",
    "browser_find_text": "Find Text",
    "browser_find_text_input": "Input a text to find",
    "browser_back_button": "Back",
    "browser_forward_button": "Forward",
    "browser_reload_button": "Reload",
    "browser_search_button": "Search",
    # Dialog
    "dialog_create_file": "Create File",
    "dialog_input_file_name": "Please enter right file name",
    "dialog_search_next": "Search next",
    "dialog_search_back": "Search back",
    # Editor
    "editor_code_result": "Code result",
    "editor_format_check": "Format checker",
    # Check Code Style Menu
    "check_code_style_menu_label": "Check Code Style",
    "yapf_reformat_label": "yapf",
    "reformat_json_label": "Reformat JSON",
    # Dock Menu
    "dock_menu_label": "Dock",
    "dock_browser_label": "New Dock Browser",
    "dock_stackoverflow_label": "New Dock Stackoverflow",
    "dock_editor_label": "New Dock Editor",
    "dock_frontengine_label": "New Dock FrontEngine",
    "dock_editor_title": "Editor",
    "dock_frontengine_title": "FrontEngine",
    "dock_browser_title": "Browser",
    # File Menu
    "file_menu_label": "File",
    "file_menu_new_file_label": "New File",
    "file_menu_open_file_label": "Open File",
    "file_menu_open_folder_label": "Open Folder",
    "file_menu_save_file_label": "Save File",
    "file_menu_encoding_label": "Encodings",
    "file_menu_font_label": "Font",
    "file_menu_font_size_label": "Font Size",
    # Help Menu
    "help_menu_label": "Help",
    "help_menu_open_github_label": "GitHub",
    "help_menu_open_doc_label": "Doc",
    "help_menu_open_about_label": "About",
    "help_menu_open_re_edge_gpt_doc_label": "Open ReEdgeGPT Doc",
    "help_menu_open_re_edge_gpt_github_label": "Open ReEdgeGPT GitHub",
    # Python Env Menu
    "python_env_menu_label": "Python Env",
    "python_env_menu_create_venv_label": "Create venv",
    "python_env_menu_pip_upgrade_label": "pip upgrade package",
    "python_env_menu_pip_label": "pip package",
    "python_env_menu_choose_interpreter_label": "Choose python interpreter",
    "python_env_menu_creating_venv_message": "Creating venv please waiting for shell exit code.",
    "python_env_menu_venv_exists": "venv already exists.",
    "python_env_menu_please_create_venv": "Please create venv first.",
    "python_env_menu_install_package_messagebox_title": "Install Package",
    "python_env_menu_install_package_messagebox_label": "What Package you want to install",
    "python_env_menu_install_or_update_package_messagebox_label": "What Package you want to install or update",
    # Run Menu
    "run_menu_label": "Run",
    "run_menu_run_program_label": "Run Program",
    "run_menu_run_on_shell_label": "Run On Shell",
    "run_menu_clear_result_label": "Clean Result",
    "run_menu_stop_all_program_label": "Stop All Program",
    "run_menu_stop_program_label": "Stop current program",
    "run_menu_run_help_label": "Run Help",
    "run_menu_shell_help_label": "Shell Help",
    "please_stop_current_running_shell": "Please stop current running shell first.",
    "please_stop_current_running_program": "Please stop current running program first.",
    "run_menu_run_help_tip": """
If you are unable to run a Python program, please make sure you are have python interpreter,
And if python conflict please choose another interpreter.
        """,
    "run_menu_shell_run_tip": """
When executing a shell command, if you encounter a decoding error, 
please make sure that the current encoding is consistent with the default encoding of the system shell.
        """,
    # Style Menu
    "style_menu_label": "UI Style",
    # Tab Menu
    "tab_menu_label": "Tab",
    "tab_menu_add_editor_label": "Add Editor Tab",
    "tab_menu_add_frontengine_label": "Add FrontEngine Tab",
    "tab_menu_add_web_label": "Add Web Browser Tab",
    "tab_menu_add_stackoverflow_label": "Add Stackoverflow Tab",
    "tab_menu_editor_tab_name": "Editor",
    "tab_menu_frontengine_tab_name": "FrontEngine",
    "tab_menu_web_tab_name": "WEB Browser",
    "tab_menu_stackoverflow_tab_name": "Stackoverflow",
    # Text Menu
    "text_menu_label": "Text",
    "text_menu_label_font": "Font",
    "text_menu_label_font_size": "Font Size",
    # System tray
    "system_tray_hide": "Hide",
    "system_tray_maximized": "Maximized",
    "system_tray_normal": "Normal",
    "system_tray_close": "Close",
    # Language Menu
    "language_menu_label": "Language",
    "language_menu_bar_english": "English",
    "language_menu_bar_traditional_chinese": "Traditional Chinese",
    "language_menu_bar_please_restart_messagebox": "Please restart",
}
